package Bundle::Locale::CLDR::Everything;

use version;

our $VERSION = version->declare('v0.32.0');

=head1 NAME Bundle::Locale::CLDR::Everything

=head1 CONTENTS

Bundle::Locale::CLDR::World 0.32.0
Locale::CLDR::Transformations 0.32.0

=cut

1;

